@@ -5,13 +5,14 @@ may or may not be program dependent
 """
 
 import os
+
 import numpy as np
 import pandas as pd
 
 
 def calculate_dqr_times(
-        obj, variable=None, txt_path=None, threshold=None,
-        qc_bit=None, return_missing=True):
+    obj, variable=None, txt_path=None, threshold=None, qc_bit=None, return_missing=True
+):
     """
     Function to retrieve start and end times of missing or bad data. Function
     will retrieve start and end time strings in a format that the DQR
@@ -63,9 +64,7 @@ def calculate_dqr_times(
         return_missing = False
 
     # Clean files. Converts from ARM to CF standards
-    obj.clean.cleanup(cleanup_arm_qc=True,
-                      handle_missing_value=True,
-                      link_qc_variables=True)
+    obj.clean.cleanup(cleanup_arm_qc=True, handle_missing_value=True, link_qc_variables=True)
     date = obj.attrs['_file_dates'][0]
     datastream = obj.attrs['_datastream']
 
@@ -82,8 +81,7 @@ def calculate_dqr_times(
         if not isinstance(threshold, int):
             int(round(threshold))
     else:
-        print('You must specify a threshold for separating ranges of' +
-              ' flagged data')
+        print('You must specify a threshold for separating ranges of' + ' flagged data')
         return
 
     # If return_missing then search for indices where data is equal to
@@ -102,7 +100,7 @@ def calculate_dqr_times(
 
             # If no bad indices then exit
             if len(idx) == 0:
-                print('No missing data for {} on '.format(var) + date)
+                print(f'No missing data for {var} on ' + date)
                 continue
             else:
                 idx = np.split(idx, splits)
@@ -115,23 +113,18 @@ def calculate_dqr_times(
                 if len(time) < 2:
                     pass
                 else:
-                    dt_times.append((obj['time'].values[time[0]],
-                                    obj['time'].values[time[-1]]))
+                    dt_times.append((obj['time'].values[time[0]], obj['time'].values[time[-1]]))
             # Convert the datetimes to strings
             time_strings = []
             for st, et in dt_times:
-                start_time = pd.to_datetime(str(st)).strftime(
-                    '%Y-%m-%d %H:%M:%S')
-                end_time = pd.to_datetime(str(et)).strftime(
-                    '%Y-%m-%d %H:%M:%S')
+                start_time = pd.to_datetime(str(st)).strftime('%Y-%m-%d %H:%M:%S')
+                end_time = pd.to_datetime(str(et)).strftime('%Y-%m-%d %H:%M:%S')
                 time_strings.append((start_time, end_time))
                 # Print times to screen
-                print('Missing Data for {} begins at: '.format(var) +
-                      start_time)
-                print('Missing Data for {} ends at: '.format(var) + end_time)
+                print(f'Missing Data for {var} begins at: ' + start_time)
+                print(f'Missing Data for {var} ends at: ' + end_time)
             if txt_path:
-                _write_dqr_times_to_txt(datastream, date, txt_path, var,
-                                        time_strings)
+                _write_dqr_times_to_txt(datastream, date, txt_path, var, time_strings)
             return time_strings
 
     # If return_bad then search for times in the corresponding qc variable
@@ -164,8 +157,7 @@ def calculate_dqr_times(
 
             # If no bad indices then exit
             if len(idx) == 0:
-                print('No bad data on ' + date + ' for selected QC bit for' +
-                      ' variable ' + var)
+                print('No bad data on ' + date + ' for selected QC bit for' + ' variable ' + var)
                 continue
             else:
                 idx = np.split(idx, splits)
@@ -178,27 +170,22 @@ def calculate_dqr_times(
                 if len(time) < 2:
                     pass
                 else:
-                    dt_times.append((obj['time'].values[time[0]],
-                                    obj['time'].values[time[-1]]))
+                    dt_times.append((obj['time'].values[time[0]], obj['time'].values[time[-1]]))
             # Convert the datetimes to strings
             time_strings = []
             for st, et in dt_times:
-                start_time = pd.to_datetime(str(st)).strftime(
-                    '%Y-%m-%d %H:%M:%S')
-                end_time = pd.to_datetime(str(et)).strftime(
-                    '%Y-%m-%d %H:%M:%S')
+                start_time = pd.to_datetime(str(st)).strftime('%Y-%m-%d %H:%M:%S')
+                end_time = pd.to_datetime(str(et)).strftime('%Y-%m-%d %H:%M:%S')
                 time_strings.append((start_time, end_time))
                 # Print times to screen
-                print('Bad Data for {} Begins at: '.format(var) + start_time)
-                print('Bad Data for {} Ends at: '.format(var) + end_time)
+                print(f'Bad Data for {var} Begins at: ' + start_time)
+                print(f'Bad Data for {var} Ends at: ' + end_time)
             if txt_path:
-                _write_dqr_times_to_txt(datastream, date, txt_path, var,
-                                        time_strings)
+                _write_dqr_times_to_txt(datastream, date, txt_path, var, time_strings)
             return time_strings
 
 
-def _write_dqr_times_to_txt(datastream, date, txt_path, variable,
-                            time_strings):
+def _write_dqr_times_to_txt(datastream, date, txt_path, variable, time_strings):
     """
     Writes flagged data time range(s) to a .txt file. The naming convention is
     dqrtimes_datastream.date.txt.
@@ -217,13 +204,25 @@ def _write_dqr_times_to_txt(datastream, date, txt_path, variable,
         List of every start and end time to be written.
 
     """
-    print('Writing data to text file for ' + datastream + ' ' + variable +
-          ' on ' + date + ' at ' + txt_path + '...', flush=True)
+    print(
+        'Writing data to text file for '
+        + datastream
+        + ' '
+        + variable
+        + ' on '
+        + date
+        + ' at '
+        + txt_path
+        + '...',
+        flush=True,
+    )
     full_path = txt_path + '/' + datastream
     if os.path.exists(full_path) is False:
         os.mkdir(full_path)
-    with open(full_path + '/dqrtimes_' + datastream + '.' + date + '.' +
-              variable + '.txt', 'w') as text_file:
+    with open(
+        full_path + '/dqrtimes_' + datastream + '.' + date + '.' + variable + '.txt',
+        'w',
+    ) as text_file:
         for st, et in time_strings:
             text_file.write('%s, ' % st)
             text_file.write('%s \n' % et)
